## Contributing to Bagua

Refer to the following guidelines to contribute new functionality or bug fixes to Bagua:

1. Create or follow an issue to discuss.
2. Write code and pass existing CI for correctness and format consistence.
3. Add unit tests for any new code you write.
4. Pass unit tests in both CPU and GPU environments.
